@@ -19,12 +19,14 @@
       session_destroy ();
       exit;
    }
-   
+   include "../sysdefs.php";
    $usr = $_SESSION['usr'];
-   $fabaixar = strip_tags($_REQUEST['fabaixar']);
-   if (0 == strpos (realpath ("../home/$usr/$fabaixar"),realpath ("../home/$usr/"))) {
-     $arxiuxbaixar = "../home/$usr/$fabaixar"; 
-     header ('Content-Disposition: attachment; filename=' . $fabaixar); 
+   $fabaixar = rawurldecode($_REQUEST['fabaixar']);
+   $pieces = explode("/", $fabaixar);
+   $arx = $pieces[count($pieces)-1];
+   if (0 === strpos (realpath ("../".mh($usr)."$usr/$fabaixar"),realpath ("../".mh($usr)."$usr/"))) {
+     $arxiuxbaixar = "../".mh($usr)."$usr/$fabaixar"; 
+     header ('Content-Disposition: attachment; filename="' . urldecode($fabaixar)).'"'; 
      header ('Content-Type: application/octet-stream');
      header ('Content-Length: ' . filesize($arxiuxbaixar));
      readfile ($arxiuxbaixar);
