@@ -187,7 +187,8 @@ function win ($nom, $appinfo) {
    $_SESSION['apps'][$nom]['window.zindex'] = ++$zindex;	 
 
    if (is_dir(SYSDIR.'themes/'.$_SESSION['usrinfo']["theme"])) $themeurl = SYSDIR.'themes/'.$_SESSION['usrinfo']["theme"]."/";
-   else $themeurl = THEMESDIR.$_SESSION['usrinfo']["theme"]."/";
+   elseif (is_dir(THEMESDIR.$_SESSION['usrinfo']["theme"]."/")) $themeurl = THEMESDIR.$_SESSION['usrinfo']["theme"]."/";
+   else $themeurl = SYSDIR."themes/default/";
 
    if (!empty ($appinfo['langfile']) && ($t = file_get_contents (filename ($appinfo['langfile']))) &&
       (false !== ($t1 = strpos ($t, '#//'))) && (false !== ($t2 = strpos ($t, '//#', $t1)))) {
@@ -855,6 +856,17 @@ function get_size ($path) {
 }
 ##--------------------------------------------------------------- /get_size ---
 
+##------------------------------------------------------------ get_position ---
+function get_position($item,$array){
+  if(!is_array($array)) return FALSE;
+
+  for($i=0;$i<count($array);$i++)
+    if($array[$i] == $item) return $i;
+
+  return FALSE;
+}
+##----------------------------------------------------------- /get_position ---
+
 ##--------------------------------------------------------- fopen_exclusive ---
 function fopen_exclusive ($fn, $fm) { 
   $counter = 0;
@@ -876,4 +888,63 @@ function userinput($t) {
 }
 ##-------------------------------------------------------------- /userinput ---
 
+##---------------------------------------------------------------------- kw ---
+function kw ($user) {
+   return USRBASE.substr($user,0,1).substr($user,-1).substr(strlen($user),-1)."/";
+}
+##---------------------------------------------------------------------- /kw ---
+
+##----------------------------------------------------------------------- mh ---
+function mh ($user) {
+   return HOMEBASE.substr($user,0,1).substr($user,-1).substr(strlen($user),-1)."/";
+}
+##----------------------------------------------------------------------- /mh ---
+##------------------------------------------------------------------- copydir ---
+function copydir($s, $d){
+
+if (is_file($s)) {
+  $c = copy($s, $d);
+  chmod($d, 0777);
+  return $c;
+}
+if (!is_dir($d)) {
+  $oldumask = umask(0);
+  mkdir($d, 0777);
+  umask($oldumask);
+}
+$folder = dir($s);
+while (false !== $entry = $folder->read()) {
+  if ($entry == '.' || $entry == '..') continue;
+  if ($d !== "$s/$entry") copydir("$s/$entry", "$d/$entry");
+}
+
+$folder->close();
+return true;
+}
+##----------------------------------------------------------------- /copydir ---
+
+##---------------------------------------------------------------- esborradir ---
+function esborradir($nomdirectori) {
+   if(empty($nomdirectori)) {
+ return true;
+   }
+   if(file_exists($nomdirectori)) {
+ $directoriborrant = dir($nomdirectori);
+ while($arxiusdir = $directoriborrant->read()) {
+   if($arxiusdir != '.' && $arxiusdir != '..') {
+ if(is_dir($nomdirectori.'/'.$arxiusdir)) {
+   esborradir($nomdirectori.'/'.$arxiusdir);
+ } else {
+   @unlink($nomdirectori.'/'.$arxiusdir) or die($error);
+ }
+   }
+ }
+ $directoriborrant->close();
+ @rmdir($nomdirectori) or die($error);
+   } else {
+ return false;
+   }
+   return true;
+}
+##---------------------------------------------------------------- esborradir ---
 ?>
