@@ -21,7 +21,7 @@
     $stats = '$hostname = ' . $_SESSION['sysinfo']['hostname'];
     foreach ($logins as $l => $v)
       $stats .= '$logins[\'' . $l . '\'] = ' . $v . ";\n";
-    if (isset ($filecount)) stats.= "\$filecount = $filecount;\n";
+    if (isset ($filecount)) $stats.= "\$filecount = $filecount;\n";
     
     $sfile = fopen ("$sfile.php", 'w');
     fwrite ($sfile, "<?PHP\nglobal \$logins;\n$stats?>");
